@@ -585,7 +585,18 @@ def shell_command(args):
                    default=10.0,
                    type=float,
                    help='When stopping, kill the subprocess after the specified timeout '
-                   'in seconds (default 10.0).')])
+                   'in seconds (default 10.0).'),
+          argument('--debounce-interval',
+                   dest='debounce_interval',
+                   default=0.0,
+                   type=float,
+                   help='After a file change, Wait until the specified interval (in '
+                   'seconds) passes with no file changes, and only then restart.'),
+          argument('--no-restart-on-command-exit',
+                   dest='restart_on_command_exit',
+                   default=True,
+                   action='store_false',
+                   help="Don't auto-restart the command after it exits.")])
 def auto_restart(args):
     """
     Command to start a long-running subprocess and restart it on matched events.
@@ -610,7 +621,10 @@ def auto_restart(args):
 
     # Handle termination signals by raising a semantic exception which will
     # allow us to gracefully unwind and stop the observer
-    termination_signals = {signal.SIGTERM, signal.SIGINT, signal.SIGHUP}
+    termination_signals = {signal.SIGTERM, signal.SIGINT}
+
+    if hasattr(signal, "SIGHUP"):
+        termination_signals.add(signal.SIGHUP)
 
     def handler_termination_signal(_signum, _frame):
         # Neuter all signals so that we don't attempt a double shutdown
@@ -630,7 +644,9 @@ def auto_restart(args):
                                ignore_patterns=ignore_patterns,
                                ignore_directories=args.ignore_directories,
                                stop_signal=stop_signal,
-                               kill_after=args.kill_after)
+                               kill_after=args.kill_after,
+                               debounce_interval_seconds=args.debounce_interval,
+                               restart_on_command_exit=args.restart_on_command_exit)
     handler.start()
     observer = Observer(timeout=args.timeout)
     try:
@@ -669,7 +685,11 @@ def main():
         return 1
     logging.getLogger('watchdog').setLevel(log_level)
 
-    args.func(args)
+    try:
+        args.func(args)
+    except KeyboardInterrupt:
+        return 130
+
     return 0
 
 
